#
# spec file for package python-greenlet
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2010 B1 Systems GmbH, Vohburg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-greenlet
Version:        0.4.7
Release:        6.2
Url:            http://pypi.python.org/pypi/greenlet
Summary:        Lightweight in-process concurrent programming
License:        MIT
Group:          Development/Libraries/Python
Source0:        http://pypi.python.org/packages/source/g/greenlet/greenlet-%{version}.zip
Patch1:         ppc64le-support.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++
BuildRequires:  python-Sphinx
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  unzip
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif

%description
The greenlet package is a spin-off of Stackless, a version of CPython
that supports micro-threads called "tasklets". Tasklets run
pseudo-concurrently (typically in a single or a few OS-level threads)
and are synchronized with data exchanges on "channels".

%package devel
Summary:        C development headers for python-greenlet
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
%if 0%{?suse_version} && 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description devel
This package contains header files required for C modules development.

%prep
%setup -q -n greenlet-%{version}
%patch1 -p1

%build
CFLAGS="%{optflags} -fno-tree-dominator-opts -fno-strict-aliasing" python setup.py build
cd doc && make html && rm _build/html/.buildinfo

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
CFLAGS="%{optflags} -fno-tree-dominator-opts -fno-strict-aliasing" python setup.py -q test

%files
%defattr(-,root,root)
%doc AUTHORS NEWS README.rst LICENSE* doc/_build/html
%{python_sitearch}/*

%files devel
%defattr(-,root,root,-)
%{_includedir}/python*/greenlet

%changelog
* Mon Jun 22 2015 tbechtold@suse.com
- update to 0.4.7:
  - Added a missing workaround for `return 0` on mips
  - Restore compatibility with Python 2.5
  - Fixed stack switching on sparc
* Wed May  6 2015 benoit.monin@gmx.fr
- update to version 0.4.6:
  * Expose `_stack_saved` property on greenlet objects, it may be
    used to introspect the amount of memory used by a saved stack,
    but the API is subject to change in the future
  * Added a workaround for `return 0` compiler optimizations on all
    architectures
  * C API typo fixes
- add -fno-strict-aliasing to CFLAGS to fix compiler warnings
- remove hidden file .buildinfo from html documentation
* Tue Nov 18 2014 toddrme2178@gmail.com
- Update to 0.4.5
  - Fixed several bugs in greenlet C API
  - Fixed a bug in multi-threaded applications, which manifested itself
    with spurious "cannot switch to a different thread" exceptions
  - Fixed some crashes on arm and mips architectures
* Thu Nov  6 2014 tserong@suse.com
- Include LICENSE and LICENSE.PSF in package
* Mon Nov  3 2014 dvaleev@suse.com
- build with -fno-tree-dominator-opts (boo#902146)
* Fri Sep 12 2014 dmueller@suse.com
- update to 0.4.4:
  - Fixed PyGreenlet_SetParent signature, thanks to BoonsNaibot
  - Fixed 64-bit Windows builds depending on wrong runtime dll
* Fri Aug 15 2014 mcihar@suse.cz
- Update to version 0.4.3:
  + Better slp_switch performance on SPARC
  + Drop support for Python 2.3
  + Fix trashcan assertions on debug builds of Python
  + Remove deprecated -fno-tree-dominator-opts compiler switch
  + Enable switch code for SunStudio on 32-bit SunOS
  + Support for abc abstract methods in greenlet subclasses
  + Support custom directories for tests
  + Document switch tracing support
* Fri Jan 17 2014 speilicke@suse.com
- Update to version 0.4.2:
  + Add .travis.yml
  + Fix 'err' may be used uninitialized in this function
  + Check _MSC_VER for msvc specific code
  + Fix slp_switch on SPARC for multi-threaded environments
  + Add support for m68k
* Tue Dec 10 2013 uweigand@de.ibm.com
- ppc64le-support.patch: Support powerpc64le-linux (ELFv2 ABI).
  Save/restore vector and floating-point registers as well on ppc.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Aug  8 2013 dvaleev@suse.com
- run tests we optflags. Stuff got compiled in %%check again.
* Tue Aug  6 2013 speilicke@suse.com
- Drop python-greenlet-aarch64-support.diff
* Mon Jun 10 2013 dmueller@suse.com
- update to 0.4.1:
  * fix segfaults when using gcc 4.8 on amd64/x86 unix
  * try to disable certain gcc 4.8 optimizations that make greenlet
    crash
  * Fix greenlet on aarch64 with gcc 4.8
  * workaround segfault on SunOS/sun4v
  * Add support for Aarch64
  * Add support for x32 psABI on x86_64
  * Changed memory constraints for assembly macro for PPC Linux
  platforms.
- remove python-greenlet-aarch64-support.diff
* Mon Apr  8 2013 matz@suse.de
- Add python-greenlet-aarch64-support.diff, for, well, aarch64
  support.
* Wed Jan  2 2013 toddrme2178@gmail.com
- Fix building on SLES
* Wed Dec 19 2012 saschpe@suse.de
- The devel subpackage contains only headers and thus is noarch
* Fri Nov 23 2012 saschpe@suse.de
- Update to version 0.4.0:
  + Greenlet has an instance dictionary now, which means it can be
    used for implementing greenlet local storage, etc. However, this
    might introduce incompatibility if subclasses have __dict__ in their
    __slots__. Classes like that will fail, because greenlet already
    has __dict__ out of the box.
  + Greenlet no longer leaks memory after thread termination, as long as
    terminated thread has no running greenlets left at the time.
  + Add support for debian sparc and openbsd5-sparc64
  + Add support for ppc64 linux
  + Don't allow greenlets to be copied with copy.copy/deepcopy
  + Fix arm32/thumb support
  + Restore greenlet's parent after kill
  + Add experimental greenlet tracing
- Changes from version 0.3.4:
  + Use plain distutils for install command, this fixes installation of
    the greenlet.h header.
  + Enhanced arm32 support
  + Fix support for Linux/S390 zSeries
  + Workaround compiler bug on RHEL 3 / CentOS 3
- Changes from version 0.3.3:
  + Use sphinx to build documentation and publish it on greenlet.rtfd.org
  + Prevent segfaults on openbsd 4/i386
  + Workaround gcc-4.0 not allowing to clobber rbx
  + Enhance test infrastructure
  + Fix possible compilation problems when including greenlet.h in C++ mode
  + Make the greenlet module work on x64 windows
  + Add a test for greenlet C++ exceptions
  + Fix compilation on Solaris with SunStudio
- Changes from version 0.3.2:
  + Fix various crashes with recent gcc versions and VC90
  + Try to fix stack save/restore on arm32
  + Store and restore the threadstate on exceptions like pypy/stackless do
  + GreenletExit is now based on BaseException on Python >= 2.5
  + Switch to using PyCapsule for Python 2.7 and 3.1
  + Port for AIX on PowerPC
  + Fix the sparc/solaris header
  + Improved build dependencies patch from flub.
  + Can't pass parent=None to greenlet.greenlet() (fixes #21)
  + Rudimentary gc support (only non-live greenlets are garbage collected though)
- Dropped the following patches (merged upstream):
  + get-rid-of-ts_origin.patch
  + i686-register-fixes.patch
  + ppc-support.patch
  + ppc64-support.patch
- Build HTML documentation
* Tue Jul  3 2012 dvaleev@suse.com
- add ppc64 platform support
- fix ppc platform
* Fri Dec 23 2011 idonmez@suse.com
- Add upstream commits 25bf29f4d3b7 and 2d5b17472757 (bnc#738431)
- Implement %%check
* Wed Sep 21 2011 saschpe@suse.de
- Spec file cleanup:
  * BuildRequire modern python-distribute instead of python-setuptools
  * No need for changing executable bits for benchmarks
  * Use SUSE version checks around specific macros
  * Only require %%{name} = %%{version} in devel package
* Fri Nov 26 2010 seife+obs@b1-systems.com
- initial package (version 0.3.1)
